@@ -34,6 +34,7 @@ sub get_extra_roles {
 my $default_attrs = {};
 
 sub add_default_attrs {
+	shift; # get rid of HPCI class name
  	my $newhash = ref($_[0]) eq 'HASH' ? shift : { @_ };
 	_merge_hash( $default_attrs, $newhash );
 }
@@ -62,7 +63,7 @@ sub group {
 		: croak("HPCI->group() requires a hashref or a hash in list form");
 	# copy the default attributes as a start
 	my $use_args = {};
-	_merge_hash( {}, $default_attrs );
+	_merge_hash( $use_args, $default_attrs );
 	my $cluster = $args->{cluster} // $use_args->{cluster}
 		// croak("HPCI->group() requires a cluster key in the argument hash");
 
@@ -90,16 +91,24 @@ sub _trigger_mkdir {
 
 =head1 VERSION
 
-Version 0.42
+Version 0.43
 
 =cut
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 our $LocalConfigFound;
 
 $LocalConfigFound = can_load( modules => { 'HPCI::LocalConfig' => undef });
 
+if( !$LocalConfigFound ) {
+	my $err = $Module::Load::Conditional::ERROR;
+	if( defined $err && $err !~ /^Could not find or check module / ) {
+		print STDERR "Conditional load of HPCI::LocalConfig failed.  Error is:\n";
+		print STDERR "$err\n";
+	}
+}
+
 =head1 SYNOPSIS
 
     use HPCI;
